@@ -111,4 +111,9 @@ class MaemoLocationProvider : public nsIGeolocationProvider,
   double mPrevLat;
   double mPrevLong;
   LocationGPSDControlInterval mInterval;
+  PRBool mIgnoreBigHErr;
+  PRInt32 mMaxHErr;
+  PRBool mIgnoreBigVErr;
+  PRInt32 mMaxVErr;
+
 };
